@@ -40,8 +40,8 @@ class KSGKipiInterface : public KIPI::Interface
 
     public:
 
-    explicit KSGKipiInterface(QObject *parent = 0);
-    ~KSGKipiInterface();
+    explicit KSGKipiInterface(QObject *parent = nullptr);
+    ~KSGKipiInterface() Q_DECL_OVERRIDE;
 
     bool addImage(const QUrl &, QString &err) Q_DECL_OVERRIDE;
     void delImage(const QUrl &) Q_DECL_OVERRIDE;
